==> react-native-template-components-1.6.3.tgz: package/README.md <==
## Usage
```js
npx react-native init MyApp --template react-native-template-components
```
### Get started
#### Run cmd
```js
Step 1: npm uninstall -g react-native-cli
Step 2: npm install -g @react-native-community/cli
Step 3: npx react-native init MyApp --template react-native-template-components
Step 4: cd MyApp
Step 5: npm run android or npm run ios
```

### Usage Packages
- [react-native-curved-bottom-bar](https://github.com/hoaphantn7604/react-native-curved-bottom-bar) A high performance, beautiful and fully customizable curved bottom navigation bar for React Native.
- [react-native-element-dropdown](https://github.com/hoaphantn7604/react-native-element-dropdown) A react-native dropdown component easy to customize for both iOS and Android.
- [react-native-utils-scale](https://github.com/hoaphantn7604/react-native-utils-scale) Provide solutions to make your app flexible for different screen sizes, different devices.
- [react-native-utils-toolkit](https://github.com/hoaphantn7604/react-native-utils-toolkit) Provide solutions to make your app flexible for different screen sizes, different devices.
- [react-native-element-image](https://github.com/hoaphantn7604/react-native-element-image) Automatically calculate width or height based on input Image component for React Native.
- [react-native-element-textinput](https://github.com/hoaphantn7604/react-native-element-textinput) A react-native TextInput component easy to customize for both iOS and Android.
- [react-native-element-timer](https://github.com/hoaphantn7604/react-native-element-timer) React Native Timer Countdown.
- [react-native-vertical-swipe-view](https://github.com/hoaphantn7604/react-native-vertical-swipe-view) React Native Vertical Swipe View.
- [react-native-checkbox-tree](https://github.com/hoaphantn7604/react-native-checkbox-tree) A simple and elegant checkbox tree for React Native.

### Demo
![](https://github.com/hoaphantn7604/file-upload/blob/master/document/template/demo1.png)
![](https://github.com/hoaphantn7604/file-upload/blob/master/document/template/demo2.png)
![](https://github.com/hoaphantn7604/file-upload/blob/master/document/template/demo3.png)
![](https://github.com/hoaphantn7604/file-upload/blob/master/document/template/demo4.png)
![](https://github.com/hoaphantn7604/file-upload/blob/master/document/dropdown/demo.gif)
![](https://github.com/hoaphantn7604/file-upload/blob/master/document/textinput/demo.gif)
![](https://github.com/hoaphantn7604/file-upload/blob/master/document/checkboxtree/demo.png)
![](https://github.com/hoaphantn7604/file-upload/blob/master/document/swipeview/demo.gif)
![](https://github.com/hoaphantn7604/file-upload/blob/master/document/timer/timer.gif)
![](https://github.com/hoaphantn7604/file-upload/blob/master/document/timer/countdown.gif)

==> react-native-template-components-1.7.4.tgz: package/README.md <==
## Usage
```js
npx react-native init MyApp --template react-native-template-components
```
### Get started
#### Run cmd
```js
Step 1: npm uninstall -g react-native-cli
Step 2: npm install -g @react-native-community/cli
Step 3: npx react-native init MyApp --template react-native-template-components
Step 4: cd MyApp
Step 5: npm run android or npm run ios
```

### Usage Packages
- [react-native-curved-bottom-bar](https://github.com/hoaphantn7604/react-native-curved-bottom-bar) A high performance, beautiful and fully customizable curved bottom navigation bar for React Native.
- [react-native-element-dropdown](https://github.com/hoaphantn7604/react-native-element-dropdown) A react-native dropdown component easy to customize for both iOS and Android.
- [react-native-utils-scale](https://github.com/hoaphantn7604/react-native-utils-scale) Provide solutions to make your app flexible for different screen sizes, different devices.
- [react-native-utils-toolkit](https://github.com/hoaphantn7604/react-native-utils-toolkit) Provide solutions to make your app flexible for different screen sizes, different devices.
- [react-native-element-image](https://github.com/hoaphantn7604/react-native-element-image) Automatically calculate width or height based on input Image component for React Native.
- [react-native-element-textinput](https://github.com/hoaphantn7604/react-native-element-textinput) A react-native TextInput component easy to customize for both iOS and Android.
- [react-native-element-timer](https://github.com/hoaphantn7604/react-native-element-timer) React Native Timer Countdown.
- [react-native-vertical-swipe-view](https://github.com/hoaphantn7604/react-native-vertical-swipe-view) React Native Vertical Swipe View.
- [react-native-checkbox-tree](https://github.com/hoaphantn7604/react-native-checkbox-tree) A simple and elegant checkbox tree for React Native.

### Demo
![](https://github.com/hoaphantn7604/file-upload/blob/master/document/template/demo1.png)
![](https://github.com/hoaphantn7604/file-upload/blob/master/document/template/demo2.png)
![](https://github.com/hoaphantn7604/file-upload/blob/master/document/template/demo3.png)
![](https://github.com/hoaphantn7604/file-upload/blob/master/document/template/demo4.png)
![](https://github.com/hoaphantn7604/file-upload/blob/master/document/dropdown/demo.gif)
![](https://github.com/hoaphantn7604/file-upload/blob/master/document/textinput/demo.png)
![](https://github.com/hoaphantn7604/file-upload/blob/master/document/checkboxtree/demo1.gif)
![](https://github.com/hoaphantn7604/file-upload/blob/master/document/swipeview/demo.gif)
![](https://github.com/hoaphantn7604/file-upload/blob/master/document/timer/timer.gif)
![](https://github.com/hoaphantn7604/file-upload/blob/master/document/timer/countdown.gif)
